from __future__ import annotations

from ..enum import StrEnum


class BaseDeviceClass(StrEnum):
    """Base class for device class."""
